==> sock-0.7.0-20180208.085849-12.jar: sock/task/clj.clj <==
(ns sock.task.clj
  "Sock Boot tasks for Clojure projects."
  {:boot/export-tasks true}
  (:require
    [boot.core :as core]
    [boot.task.built-in :as built-in]
    [sock.init]
    [sock.lib.core :refer [apply-kw]]
    [sock.task.deps :refer [deps test-deps]])
  (:refer-clojure :exclude [test]))

(core/deftask environ
  "If 'environ is a dependency of the current project then require and run the
   boot-environ task, otherwise do nothing."
  [_ environ OPTIONS edn "Options for boot-environ task."]
  (let [environ? (some #(= (first %) 'environ) (:dependencies (core/get-env)))]
    (if environ?
      (do
        (core/set-env! :dependencies #(conj % '[boot-environ "1.1.0" :scope "test"]))
        (require 'environ.boot)
        (let [boot-environ (resolve 'environ.boot/environ)]
          (apply-kw boot-environ environ)))
      identity)))

(core/deftask midje
  "If 'midje is a dependency of the current project then require and run the
   zhuangxm/boot-midje Midje test runner, otherwise do nothing."
  [_ midje OPTIONS edn "Options for zhuangxm/boot-midje task."]
  (let [midje? (some #(= (first %) 'midje) (:dependencies (core/get-env)))]
    (if midje?
      (do
        (core/set-env! :dependencies #(conj % '[zhuangxm/boot-midje "0.1.2" :scope "test"]))
        (require 'zhuangxm.boot-midje)
        (let [boot-midje (resolve 'zhuangxm.boot-midje/midje)]
          (apply-kw boot-midje midje)))
      identity)))

(core/deftask clojure-test
  "Require and run the clojure.test test runner."
  [_ opts OPTIONS edn "Options for adzerk/boot-test task."]
  (core/set-env! :dependencies #(conj % '[adzerk/boot-test "1.2.0" :scope "test"]))
  (require 'adzerk.boot-test)
  (let [boot-test (resolve 'adzerk.boot-test/test)]
    (apply-kw boot-test opts)))

(core/deftask build
  "Resolve dependencies, create project pom.xml file and build a jar file."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ environ    OPTIONS edn "Options for boot-environ task."
   _ pom        OPTIONS edn "Options for built-in/pom task."]
  (comp (apply-kw deps tools-deps)
        (plumbing.clj/environ :environ environ)
        (apply-kw built-in/pom pom)))

;;; This prevents a name collision WARNING between the test task and
;;; clojure.core/test, a function that nobody really uses or cares
;;; about.
(ns-unmap 'boot.user 'test)

(core/deftask test
  "Resolve dependencies including :test alias and run Midje tests."
  [_ tools-deps OPTIONS edn "seancorfield/boot-tools-deps task."
   _ environ    OPTIONS edn "Options for boot-environ task."
   _ midje      OPTIONS edn "Options for zhuangxm/boot-midje task."]
  (comp (test-deps :tools-deps tools-deps)
        (plumbing.clj/environ :environ environ)
        (plumbing.clj/midje :midje midje)
        (plumbing.clj/clojure-test)))

(core/deftask local
  "Build then install project jar file to local Maven repository."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ jar        OPTIONS edn "Options for built-in/jar task."
   _ install    OPTIONS edn "Options for built-in/install task."]
  (comp (build :tools-deps tools-deps
               :pom pom)
        (apply-kw built-in/jar jar)
        (apply-kw built-in/install install)))

(core/deftask snapshot
  "Build then deploy project jar file to company snapshots repository."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ jar        OPTIONS edn "Options for built-in/jar task."
   _ push       OPTIONS edn "Options for built-in/push task."]
  (let [push' (merge {:repo "company-snapshots"} push)]
    (comp (build :tools-deps tools-deps
                 :pom pom)
          (apply-kw built-in/jar jar)
          (apply-kw built-in/push push'))))

(core/deftask release
  "Build then deploy project jar file to company releases repository."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ jar        OPTIONS edn "Options for built-in/jar task."
   _ push       OPTIONS edn "Options for built-in/push task."]
  (let [push' (merge {:repo "company-releases"} push)]
    (comp (build :tools-deps tools-deps
                 :pom pom)
          (apply-kw built-in/jar jar)
          (apply-kw built-in/push push'))))

(core/deftask assemble
  "Build, add jar entries from dependencies to fileset and writes output files
   to the target directory. Mainly used for server projects which subsequently
   copy the target directory into a Docker image."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ uber       OPTIONS edn "Options for built-in/uber task."
   _ target     OPTIONS edn "Options for built-in/target task."]
  (comp (build :tools-deps tools-deps
               :pom        pom)
        (apply-kw built-in/uber uber)
        (apply-kw built-in/target target)))

==> sock-0.7.0-20180208.090117-13.jar: sock/task/clj.clj <==
(ns sock.task.clj
  "Sock Boot tasks for Clojure projects."
  {:boot/export-tasks true}
  (:require
    [boot.core :as core]
    [boot.task.built-in :as built-in]
    [sock.init]
    [sock.lib.core :refer [apply-kw]]
    [sock.task.deps :refer [deps test-deps]])
  (:refer-clojure :exclude [test]))

(core/deftask environ
  "If 'environ is a dependency of the current project then require and run the
   boot-environ task, otherwise do nothing."
  [_ environ OPTIONS edn "Options for boot-environ task."]
  (let [environ? (some #(= (first %) 'environ) (:dependencies (core/get-env)))]
    (if environ?
      (do
        (core/set-env! :dependencies #(conj % '[boot-environ "1.1.0" :scope "test"]))
        (require 'environ.boot)
        (let [boot-environ (resolve 'environ.boot/environ)]
          (apply-kw boot-environ environ)))
      identity)))

(core/deftask midje
  "If 'midje is a dependency of the current project then require and run the
   zhuangxm/boot-midje Midje test runner, otherwise do nothing."
  [_ midje OPTIONS edn "Options for zhuangxm/boot-midje task."]
  (let [midje? (some #(= (first %) 'midje) (:dependencies (core/get-env)))]
    (if midje?
      (do
        (core/set-env! :dependencies #(conj % '[zhuangxm/boot-midje "0.1.2" :scope "test"]))
        (require 'zhuangxm.boot-midje)
        (let [boot-midje (resolve 'zhuangxm.boot-midje/midje)]
          (apply-kw boot-midje midje)))
      identity)))

(core/deftask clojure-test
  "Require and run the clojure.test test runner."
  [_ opts OPTIONS edn "Options for adzerk/boot-test task."]
  (core/set-env! :dependencies #(conj % '[adzerk/boot-test "1.2.0" :scope "test"]))
  (require 'adzerk.boot-test)
  (let [boot-test (resolve 'adzerk.boot-test/test)]
    (apply-kw boot-test opts)))

(core/deftask build
  "Resolve dependencies, create project pom.xml file and build a jar file."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ environ    OPTIONS edn "Options for boot-environ task."
   _ pom        OPTIONS edn "Options for built-in/pom task."]
  (comp (apply-kw deps tools-deps)
        (environ :environ environ)
        (apply-kw built-in/pom pom)))

;;; This prevents a name collision WARNING between the test task and
;;; clojure.core/test, a function that nobody really uses or cares
;;; about.
(ns-unmap 'boot.user 'test)

(core/deftask test
  "Resolve dependencies including :test alias and run Midje tests."
  [_ tools-deps OPTIONS edn "seancorfield/boot-tools-deps task."
   _ environ    OPTIONS edn "Options for boot-environ task."
   _ midje      OPTIONS edn "Options for zhuangxm/boot-midje task."]
  (comp (test-deps :tools-deps tools-deps)
        (environ :environ environ)
        (midje :midje midje)
        (clojure-test)))

(core/deftask local
  "Build then install project jar file to local Maven repository."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ jar        OPTIONS edn "Options for built-in/jar task."
   _ install    OPTIONS edn "Options for built-in/install task."]
  (comp (build :tools-deps tools-deps
               :pom pom)
        (apply-kw built-in/jar jar)
        (apply-kw built-in/install install)))

(core/deftask snapshot
  "Build then deploy project jar file to company snapshots repository."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ jar        OPTIONS edn "Options for built-in/jar task."
   _ push       OPTIONS edn "Options for built-in/push task."]
  (let [push' (merge {:repo "company-snapshots"} push)]
    (comp (build :tools-deps tools-deps
                 :pom pom)
          (apply-kw built-in/jar jar)
          (apply-kw built-in/push push'))))

(core/deftask release
  "Build then deploy project jar file to company releases repository."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ jar        OPTIONS edn "Options for built-in/jar task."
   _ push       OPTIONS edn "Options for built-in/push task."]
  (let [push' (merge {:repo "company-releases"} push)]
    (comp (build :tools-deps tools-deps
                 :pom pom)
          (apply-kw built-in/jar jar)
          (apply-kw built-in/push push'))))

(core/deftask assemble
  "Build, add jar entries from dependencies to fileset and writes output files
   to the target directory. Mainly used for server projects which subsequently
   copy the target directory into a Docker image."
  [_ tools-deps OPTIONS edn "Options for seancorfield/boot-tools-deps task."
   _ pom        OPTIONS edn "Options for built-in/pom task."
   _ uber       OPTIONS edn "Options for built-in/uber task."
   _ target     OPTIONS edn "Options for built-in/target task."]
  (comp (build :tools-deps tools-deps
               :pom        pom)
        (apply-kw built-in/uber uber)
        (apply-kw built-in/target target)))
